# SAP Signavio Integration
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/sap-signavio-integration#introduction)
  * [Benefits of the Integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration#benefits-of-the-integration)
  * [Scope of the Integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration#scope-of-the-integration)
  * [Getting Started with the Integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration#getting-started-with-the-integration)
  * [Filtering for Linked Fact Sheets in Inventory and Reports](https://help.sap.com/docs/leanix/ea/sap-signavio-integration#filtering-for-linked-fact-sheets-in-inventory-and-reports)
  * [Leveraging Reports for Analysis](https://help.sap.com/docs/leanix/ea/sap-signavio-integration#leveraging-reports-for-analysis)
  * [Accessing Linked Items across SAP LeanIX and SAP Signavio](https://help.sap.com/docs/leanix/ea/sap-signavio-integration#accessing-linked-items-across-sap-leanix-and-sap-signavio)
  * [Viewing Synchronization Logs](https://help.sap.com/docs/leanix/ea/sap-signavio-integration#viewing-synchronization-logs)


The integration between SAP LeanIX and SAP Signavio enables seamless data synchronization, ensuring both systems have consistent and up-to-date information about business processes and IT systems. Learn how to set up the integration and how to map and sync data between SAP LeanIX and SAP Signavio.
